# frozen_string_literal: true

require 'capital_on_tap/version'
require 'capital_on_tap/configuration'
require 'capital_on_tap/connection'
require 'capital_on_tap/auth'
require 'capital_on_tap/application'

module CapitalOnTap
  module_function

  def configuration
    @configuration ||= Configuration.new
  end

  def connection
    @connection ||= setup_connection!
  end

  def configure
    yield(configuration)
  end

  def setup_connection!
    token_params = CapitalOnTap::Auth.obtain_token

    raise "ERROR: #{token_params[:error_description]}" if token_params[:error]

    @connection = Connection.new(
      access_token: token_params[:access_token],
      expires_in: token_params[:expires_in],
      refresh_token: token_params[:refresh_token]
    )
  end
end
