# frozen_string_literal: true

require 'forwardable'

module CapitalOnTap
  class Response
    extend Forwardable

    def_delegators :@http_response, :body, :status, :success?, :headers

    def initialize(http_response)
      @http_response = http_response
    end

    def error
      @http_response.body&.dig(:errorMessage) || @http_response.body&.dig(:error)
    end

    def metadata
      @http_response.body&.dig(:metaData)
    end

    def invalid_token?
      auth_failure = @http_response.headers&.dig('www-authenticate')

      return false unless auth_failure

      auth_failure.match?('invalid_token')
    end
  end
end
